@@ -11,11 +11,11 @@ URL::Normalize - Normalize/optimize URLs.
 
 =head1 VERSION
 
-Version 0.37
+Version 0.38
 
 =cut
 
-our $VERSION = '0.37';
+our $VERSION = '0.38';
 
 =head1 SYNOPSIS
 
@@ -164,7 +164,7 @@ sub URI {
     my $URI = undef;
 
     eval {
-        $URI = URI->new( $self->url );
+        $URI = URI->new( $self->url )->canonical;
     };
 
     if ( $@ ) {
